==> v13.5.0.tar.gz: sharex/ShareX.HelpersLib/CLI/CLICommandAction.cs <==
﻿#region License Information (GPL v3)

/*
    ShareX - A program that allows you to take screenshots and share any file type
    Copyright (c) 2007-2020 ShareX Team

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

    Optionally you can also view the license at <http://www.gnu.org/licenses/>.
*/

#endregion License Information (GPL v3)

using System;
using System.Collections.Generic;

namespace ShareX.HelpersLib
{
    public class CLICommandAction
    {
        public string[] Commands;
        public Action DefaultAction;
        public Action<string> TextAction;
        public Action<int> NumberAction;

        public CLICommandAction(params string[] commands)
        {
            Commands = commands;
        }

        public bool CheckCommands(List<CLICommand> commands)
        {
            foreach (CLICommand command in commands)
            {
                foreach (string text in Commands)
                {
                    if (command.CheckCommand(text))
                    {
                        ExecuteAction(command.Parameter);
                        return true;
                    }
                }
            }

            return false;
        }

        private void ExecuteAction(string parameter)
        {
            if (DefaultAction != null)
            {
                DefaultAction();
            }
            else if (!string.IsNullOrEmpty(parameter))
            {
                if (TextAction != null)
                {
                    TextAction(parameter);
                }
                else if (NumberAction != null)
                {
                    int num;

                    if (int.TryParse(parameter, out num))
                    {
                        NumberAction(num);
                    }
                }
            }
        }
    }
}

==> v13.6.0.tar.gz: sharex/ShareX.HelpersLib/CLI/CLICommandAction.cs <==
﻿#region License Information (GPL v3)

/*
    ShareX - A program that allows you to take screenshots and share any file type
    Copyright (c) 2007-2021 ShareX Team

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

    Optionally you can also view the license at <http://www.gnu.org/licenses/>.
*/

#endregion License Information (GPL v3)

using System;
using System.Collections.Generic;

namespace ShareX.HelpersLib
{
    public class CLICommandAction
    {
        public string[] Commands;
        public Action DefaultAction;
        public Action<string> TextAction;
        public Action<int> NumberAction;

        public CLICommandAction(params string[] commands)
        {
            Commands = commands;
        }

        public bool CheckCommands(List<CLICommand> commands)
        {
            foreach (CLICommand command in commands)
            {
                foreach (string text in Commands)
                {
                    if (command.CheckCommand(text))
                    {
                        ExecuteAction(command.Parameter);
                        return true;
                    }
                }
            }

            return false;
        }

        private void ExecuteAction(string parameter)
        {
            if (DefaultAction != null)
            {
                DefaultAction();
            }
            else if (!string.IsNullOrEmpty(parameter))
            {
                if (TextAction != null)
                {
                    TextAction(parameter);
                }
                else if (NumberAction != null)
                {
                    if (int.TryParse(parameter, out int num))
                    {
                        NumberAction(num);
                    }
                }
            }
        }
    }
}
